Mise à jour en cours...
Mise à jour reussi...
Echec mise à jour...
sorties

1 | Compresseur | 0 |
100 | Détendeur | 1 |
0 | Distri chaud/froid | 0 |
6 | Capteur | 0 |
2 | Vanne inversion | 0 |
4 | Cordon chauffant | 0 |
101 | Vitesse capteur | 0 |
5 | Fonction externe | 0 |
0 | Prod chaud/froid | 0 |
0 | Test | 0 |
0 | Chauffage autorisé | 1 |
0 | Rafraichissement autorisé | 0 |
7 | Circulateur technique | 0 |
3 | Appoint chauffage | 0 |
8 | Circulateur zone 1 | 0 |
11 | Circulateur zone 2 | 0 |
0 | Pas d'alarme | 1 |
0 | Vitesse compresseur | 0 |